﻿(function () {
    "use strict";

    var _customer = null;
    var _customerIdx = null;

    WinJS.UI.Pages.define("/pages/customerDetails/customerDetails.html", {
        // This function is called whenever a user navigates to this page. It
        // populates the page elements with the app's data.
        ready: function (element, options) {
            var pageControl = this;
            _customerIdx = options.customerIdx;

            Northwind.Data.getCustomers().then(function (customerList) {
                _customer = customerList.getAt(_customerIdx);

                // Set the page title to the company name.
                $(".pagetitle").text(_customer.companyName);

                var customerFields = $(".customerFields").get(0);

                // Binding the customer to the customer fields.
                WinJS.Binding.processAll(customerFields, _customer);

                $("#saveCommand").bind("click", pageControl.saveCustomer);
                $("#ordersCommand").bind("click", pageControl.customerOrders);
            });
        },

        saveCustomer: function () {
            // Display a message that saving has started.
            var $pageStatus = $(".pageStatus");
            $pageStatus.text("Saving...");
            $pageStatus.removeClass("pageStatusHidden");

            // Get the values from the UI.
            _customer.companyName = $("#companyNameInput").val();
            _customer.contactName = $("#contactNameInput").val();
            _customer.contactTitle = $("#contactTitleInput").val();
            _customer.phone = $("#contactPhoneInput").val();
            _customer.fax = $("#contactFaxInput").val();
            _customer.region = $("#contactRegionInput").val();

            // Save the customer.
            Northwind.Data.saveCustomer(_customer).then(function (response) {
                // Was save successful?
                if (response.saved === true) {
                    // Display a message that save was successful.
                    $pageStatus.text("Saved Successfully").addClass("pageStatusSuccess");
                    // Update the page title.
                    $(".pagetitle").text(_customer.companyName);
                } else {
                    // Display the failed message.
                    $pageStatus.addClass("pageStatusFail");
                    $pageStatus.text("Error: " + response.message);
                }
            });
        },

        customerOrders: function () {
            WinJS.Navigation.navigate("/pages/customerOrders/customerOrders.html", { customerIdx: _customerIdx });
        }
    });
})();
