﻿// For an introduction to the Page Control template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232511
(function () {
    "use strict";

    var _customer = null;
    var _pageControl = null;
    var _customerIdx = null;

    WinJS.UI.Pages.define("/pages/customerOrders/customerOrders.html", {
        // This function is called whenever a user navigates to this page. It
        // populates the page elements with the app's data.
        ready: function (element, options) {
            _pageControl = this;
            _customerIdx = options.customerIdx;

            // Get the customer.
            Northwind.Data.getCustomers().then(function (customerList) {
                _customer = customerList.getAt(_customerIdx);

                // Get the customer orders.
                _customer.getOrders().then(function (orders) {
                    var data = [];
                    var categories = [];

                    // Loop through the orders and build the array of data and text for the X axis.
                    orders.forEach(function (order) {
                        data.push(order.SubTotal);
                        categories.push(order.OrderID);
                    });

                    var columnSeries = new Telerik.UI.Chart.ColumnSeries();
                    columnSeries.data = data;

                    // Get the chart control.
                    var ordersChart = element.querySelector("#ordersChart").winControl;
                    ordersChart.series.push(columnSeries);

                    // Format the text for the Y axis.
                    ordersChart.valueAxis.labels.format = "{0:C}";

                    ordersChart.categoryAxis.categories = categories;

                    // Format the text for the X axis.
                    ordersChart.categoryAxis.labels.format = "Order # {0}";

                    // Listen for the click event.
                    ordersChart.addEventListener("seriesclick", _pageControl.ordersChartSeriesClick, false);

                    ordersChart.refresh();
                });
            });
        },

        ordersChartSeriesClick: function (e) {
            _customer.getOrders().then(function (orders) {
                _pageControl.element.querySelector(".customerOrders .orderFields").removeClass("orderFieldsHidden");

                var order = JSON.find({ data: orders, attr: "OrderID", value: e.category });

                // Wrap the order object to add the shortOrderDate and shortShippedDate methods.
                var displayOrder = {
                    order: order,
                    get shortOrderDate() {
                        var orderDate = new Date(this.order.OrderDate);
                        return (orderDate.getMonth() + 1) + "/" + orderDate.getDate() + "/" + orderDate.getFullYear();
                    },
                    get shortShippedDate() {
                        var shippedDate = new Date(order.ShippedDate);
                        return (shippedDate.getMonth() + 1) + "/" + shippedDate.getDate() + "/" + shippedDate.getFullYear();
                    }
                };

                WinJS.Binding.processAll($(".orderFields").get(0), displayOrder);
                /*
                _pageControl.element.querySelector("#orderIdValue").innerHTML = order.OrderID;

                var orderDate = new Date(order.OrderDate);
                _pageControl.element.querySelector("#orderDateValue").innerHTML = (orderDate.getMonth() + 1) + "/" + orderDate.getDate() + "/" + orderDate.getFullYear();

                _pageControl.element.querySelector("#shipNameValue").innerHTML = order.ShipName;

                var shippedDate = new Date(order.ShippedDate);
                _pageControl.element.querySelector("#shippedDateValue").innerHTML = (shippedDate.getMonth() + 1) + "/" + shippedDate.getDate() + "/" + shippedDate.getFullYear();
                */
            });
        }
    });
})();
