﻿(function () {
    "use strict";

    /*
     * PRIVATE VARIABLES
     */

    // Define the root url for the RESTful service and the service calls.
    var _serviceUrl = "http://192.168.56.101/NorthwindService/RestService";
    var _getCustomersUrl = _serviceUrl + "/GetCustomers";
    var _saveCustomerUrl = _serviceUrl + "/SaveCustomer";
    var _getCustomerOrdersUrl = _serviceUrl + "/GetCustomerOrders";

    // Define the data lists.
    var _groupsList = new WinJS.Binding.List([
        { key: 1, title: "Customers", imageCssClass: "groupImage customersImage" },
        { key: 2, title: "Employees", imageCssClass: "groupImage employeesImage" },
        { key: 3, title: "Orders", imageCssClass: "groupImage ordersImage" }
    ]);
    var _customersList = null;


    /*
     * PRIVATE FUNCTIONS
     */

    // Prepare settings for posting to the RESTful service.
    function preparePostSettings(url, jsonObject) {
        return {
            url: url,
            type: "POST",
            headers: { "Content-Type": "text/xml;" },
            data: '<string xmlns="http://schemas.microsoft.com/2003/10/Serialization/">' + JSON.stringify(jsonObject) + '</string>'
        }
    }

    // Get the JSON object from the WinJS.xhr result.
    function getJsonFromResult(result) {
        var json = null;

        if (result.responseXML.firstChild != null) {
            var jsonData = result.responseXML.firstChild.textContent;
            if (jsonData != undefined && jsonData.length > 0) {
                json = JSON.parse(jsonData);
            }
        }

        return json;
    };

    // Get the orders for a customer.
    var getCustomerOrders = function () {
        var customer = this;
        return new WinJS.Promise(function (complete, error, success) {
            if (customer.orders === undefined) {
                WinJS.xhr({ url: _getCustomerOrdersUrl + "/" + customer.customerID }).then(function (result) {
                    customer.orders = getJsonFromResult(result);
                    complete(customer.orders);
                });
            } else {
                complete(customer.orders);
            }
        });
    }

    // Get all the customers from the service.
    function getCustomers() {
        /// <return>WinJS.Promise to return a WinJS.Binding.List of customers.</return>

        return new WinJS.Promise(function (complete, error, success) {
            // If called for the first time, then get the list from the service.
            if (_customersList == null) {
                _customersList = new WinJS.Binding.List();

                WinJS.xhr({ url: _getCustomersUrl }).then(function (result) {
                    var customers = getJsonFromResult(result);

                    if (customers != null) {
                        customers.forEach(function (customer) {
                            _customersList.push({
                                key: customer.CustomerID,
                                customerID: customer.CustomerID,
                                contactName: customer.ContactName,
                                contactTitle: customer.ContactTitle,
                                companyName: customer.CompanyName,
                                address: customer.Address,
                                city: customer.City,
                                region: customer.Region,
                                country: customer.Country,
                                postalCode: customer.PostalCode,
                                fax: customer.Fax,
                                phone: customer.Phone,
                                getOrders: getCustomerOrders
                            });
                        });
                        complete(_customersList);
                    }
                });
            } else {
                complete(_customersList);
            }
        });
    };

    // Save a customer.
    var saveCustomer = function (customer) {
        /// <param name="customer" type="json">The customer to be saved.</param>
        /// <return>JSON object containing the save results from the service.</return>

        return new WinJS.Promise(function (complete, error, success) {
            WinJS.xhr(preparePostSettings(_saveCustomerUrl, customer)).then(function (result) {
                var response = getJsonFromResult(result);
                if (response != null) {
                    complete(response);
                }
            });
        });
    }

    /*
     * PUBLIC FUNCTIONS
     */

    WinJS.Namespace.define("Northwind.Data", {
        groupsList: _groupsList,
        getCustomers: getCustomers,
        saveCustomer: saveCustomer
    });
})();